@@ -8,9 +8,9 @@ import os
 import pkg_resources
 
 
-def prinfPath():{
-    print("!!! " + os.path.dirname(os.path.realpath(__file__)) + "haarcascades/haarcascade_frontalface_default.xml"),
-}
+def prinfPath():
+    print("!!!" + os.path.dirname(os.path.realpath(__file__)) + "haarcascades/haarcascade_frontalface_default.xml")
+
 
 #打码函数
 # size为打码的方块大小
